import { EVMBlockchainIncludingTestnet } from '@crossmint/common-sdk-base';
export { EVMBlockchainIncludingTestnet as Blockchain, EVMBlockchainIncludingTestnet, blockchainToChainId } from '@crossmint/common-sdk-base';
import * as viem from 'viem';
import { Hex, LocalAccount, EIP1193Provider, HttpTransport, Chain, PublicClient } from 'viem';
import { EntryPointVersion } from 'permissionless/_types/types';
import { TORUS_NETWORK_TYPE } from '@web3auth/single-factor-auth';
import { EntryPointVersion as EntryPointVersion$1, EntryPoint } from 'permissionless/types/entrypoint';
import { KernelSmartAccount } from '@zerodev/sdk';
import { SmartAccountClient } from 'permissionless';
import { SmartAccount, SmartAccountSigner } from 'permissionless/accounts';
import * as viem_chains from 'viem/chains';

type PasskeyValidatorSerializedData = {
    passkeyServerUrl: string;
    credentials: string;
    entryPoint: Hex;
    validatorAddress: Hex;
    pubKeyX: string;
    pubKeyY: string;
    authenticatorIdHash: Hex;
};

type StoreAbstractWalletInput = {
    type: string;
    smartContractWalletAddress: string;
    signerData: SignerData;
    sessionKeySignerAddress?: string;
    version: number;
    baseLayer: string;
    chainId: number;
    entryPointVersion: EntryPointVersion;
};
type SignerData = EOASignerData | PasskeySignerData;
interface EOASignerData {
    eoaAddress: string;
    type: "eoa";
}
type PasskeySignerData = PasskeyValidatorSerializedData & {
    passkeyName: string;
    domain: string;
    type: "passkeys";
};

type SmartWalletSDKInitParams = {
    clientApiKey: string;
};
type WhitelabelUserParams = {
    /**
     * A unique identifier for the user. This must match the value of the identifier within the JWT
     * that is specified in the project settings (typically `sub`).
     */
    id: string;
    jwt: string;
};
type UserParams = WhitelabelUserParams;
type Web3AuthSigner = {
    type: "WEB3_AUTH";
    clientId: string;
    verifierId: string;
    web3AuthNetwork: TORUS_NETWORK_TYPE;
    jwt: string;
};
type ViemAccount = {
    type: "VIEM_ACCOUNT";
    account: LocalAccount & {
        source: "custom";
    };
};
type PasskeySigner = {
    type: "PASSKEY";
    /**
     * Displayed to the user during passkey registration or signing prompts.
     */
    passkeyName: string;
};
type EOASigner = EIP1193Provider | Web3AuthSigner | ViemAccount;
interface WalletConfig {
    signer: EOASigner | PasskeySigner;
}
type EntryPointDetails = {
    version: EntryPointVersion$1;
    address: EntryPoint;
};

declare class LoggerWrapper {
    private extraInfo;
    private logIdempotencyKey;
    constructor(className: string, extraInfo?: {}, logIdempotencyKey?: string);
    private logInput;
    private logOutput;
    private logError;
    protected logPerformance<T>(name: string, cb: () => Promise<T>): Promise<T>;
}

declare abstract class BaseCrossmintService extends LoggerWrapper {
    protected crossmintAPIHeaders: Record<string, string>;
    protected crossmintBaseUrl: string;
    private static urlMap;
    constructor(apiKey: string);
    protected fetchCrossmintAPI(endpoint: string, options: {
        body?: string | undefined;
        method: string;
    } | undefined, onServerErrorMessage: string, authToken?: string): Promise<any>;
    protected getUrlFromEnv(environment: string): string;
}

declare class CrossmintWalletService extends BaseCrossmintService {
    storeAbstractWallet(user: UserParams, input: StoreAbstractWalletInput): Promise<any>;
    getAbstractWalletEntryPointVersion(user: UserParams, chain: EVMBlockchainIncludingTestnet): Promise<any>;
    getPasskeySigner(user: UserParams): Promise<PasskeySignerData | null>;
    fetchNFTs(address: string, chain: EVMBlockchainIncludingTestnet): Promise<any>;
    getPasskeyServerUrl(user: UserParams): string;
}

interface EVMToken {
    chain: EVMBlockchainIncludingTestnet;
    contractAddress: string;
}
interface NFTEVMToken extends EVMToken {
    tokenId: string;
    type: "nft";
}
interface SFTEVMToken extends EVMToken {
    tokenId: string;
    type: "sft";
}
interface ERC2OEVMToken extends EVMToken {
    type: "ft";
}
type TokenType = "nft" | "sft" | "ft";

type ERC20TransferType = {
    token: ERC2OEVMToken;
    amount: bigint;
};
type SFTTransferType = {
    token: SFTEVMToken;
    quantity: number;
};
type NFTTransferType = {
    token: NFTEVMToken;
};
type TransferType = ERC20TransferType | SFTTransferType | NFTTransferType;

/**
 * Smart wallet interface for EVM chains enhanced with Crossmint capabilities.
 * Core functionality is exposed via [viem](https://viem.sh/) clients within the `client` property of the class.
 */
declare class EVMSmartWallet extends LoggerWrapper {
    private readonly crossmintService;
    readonly chain: EVMBlockchainIncludingTestnet;
    /**
     * [viem](https://viem.sh/) clients that provide an interface for core wallet functionality.
     */
    readonly client: {
        /**
         * An interface to interact with the smart wallet, execute transactions, sign messages, etc.
         */
        wallet: SmartAccountClient<EntryPoint, HttpTransport, Chain, SmartAccount<EntryPoint>>;
        /**
         * An interface to read onchain data, fetch transactions, retrieve account balances, etc. Corresponds to public [JSON-RPC API](https://ethereum.org/en/developers/docs/apis/json-rpc/) methods.
         */
        public: PublicClient;
    };
    private readonly kernel;
    constructor(crossmintService: CrossmintWalletService, account: KernelSmartAccount<EntryPoint, HttpTransport>, publicClient: PublicClient<HttpTransport>, chain: EVMBlockchainIncludingTestnet);
    /**
     * The address of the smart wallet.
     */
    get address(): `0x${string}`;
    /**
     * @returns The transaction hash.
     */
    transfer(toAddress: string, config: TransferType): Promise<string>;
    /**
     * @returns A list of NFTs owned by the wallet.
     */
    nfts(): Promise<any>;
}

declare const getUrlProviderByBlockchain: (chain: EVMBlockchainIncludingTestnet) => string;
declare const getBlockExplorerByBlockchain: (chain: EVMBlockchainIncludingTestnet) => string;
declare function getTickerByBlockchain(chain: EVMBlockchainIncludingTestnet): string;
declare function getTickerNameByBlockchain(chain: EVMBlockchainIncludingTestnet): string;
declare const getZeroDevProjectIdByBlockchain: (chain: EVMBlockchainIncludingTestnet) => string;
declare const getViemNetwork: (cmChain: EVMBlockchainIncludingTestnet) => {
    blockExplorers: {
        readonly default: {
            readonly name: "Etherscan";
            readonly url: "https://etherscan.io";
            readonly apiUrl: "https://api.etherscan.io/api";
        };
    };
    contracts: {
        readonly ensRegistry: {
            readonly address: "0x00000000000C2E074eC69A0dFb2997BA6C7d2e1e";
        };
        readonly ensUniversalResolver: {
            readonly address: "0xce01f8eee7E479C928F8919abD53E553a36CeF67";
            readonly blockCreated: 19258213;
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 14353601;
        };
    };
    id: 1;
    name: "Ethereum";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://cloudflare-eth.com"];
        };
    };
    sourceId?: number | undefined;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Etherscan";
            readonly url: "https://goerli.etherscan.io";
            readonly apiUrl: "https://api-goerli.etherscan.io/api";
        };
    };
    contracts: {
        readonly ensRegistry: {
            readonly address: "0x00000000000C2E074eC69A0dFb2997BA6C7d2e1e";
        };
        readonly ensUniversalResolver: {
            readonly address: "0xfc4AC75C46C914aF5892d6d3eFFcebD7917293F1";
            readonly blockCreated: 10339206;
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 6507670;
        };
    };
    id: 5;
    name: "Goerli";
    nativeCurrency: {
        readonly name: "Goerli Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc.ankr.com/eth_goerli"];
        };
    };
    sourceId?: number | undefined;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Etherscan";
            readonly url: "https://sepolia.etherscan.io";
            readonly apiUrl: "https://api-sepolia.etherscan.io/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 751532;
        };
        readonly ensRegistry: {
            readonly address: "0x00000000000C2E074eC69A0dFb2997BA6C7d2e1e";
        };
        readonly ensUniversalResolver: {
            readonly address: "0xc8Af999e38273D658BE1b921b88A9Ddf005769cC";
            readonly blockCreated: 5317080;
        };
    };
    id: 11155111;
    name: "Sepolia";
    nativeCurrency: {
        readonly name: "Sepolia Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc.sepolia.org"];
        };
    };
    sourceId?: number | undefined;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "PolygonScan";
            readonly url: "https://polygonscan.com";
            readonly apiUrl: "https://api.polygonscan.com/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 25770160;
        };
    };
    id: 137;
    name: "Polygon";
    nativeCurrency: {
        readonly name: "MATIC";
        readonly symbol: "MATIC";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://polygon-rpc.com"];
        };
    };
    sourceId?: number | undefined;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "PolygonScan";
            readonly url: "https://amoy.polygonscan.com";
            readonly apiUrl: "https://api-amoy.polygonscan.com/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 3127388;
        };
    };
    id: 80002;
    name: "Polygon Amoy";
    nativeCurrency: {
        readonly name: "MATIC";
        readonly symbol: "MATIC";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc-amoy.polygon.technology"];
        };
    };
    sourceId?: number | undefined;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Optimism Explorer";
            readonly url: "https://optimistic.etherscan.io";
            readonly apiUrl: "https://api-optimistic.etherscan.io/api";
        };
    };
    contracts: {
        readonly disputeGameFactory: {
            readonly 1: {
                readonly address: "0xe5965Ab5962eDc7477C8520243A95517CD252fA9";
            };
        };
        readonly l2OutputOracle: {
            readonly 1: {
                readonly address: "0xdfe97868233d1aa22e815a266982f2cf17685a27";
            };
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 4286263;
        };
        readonly portal: {
            readonly 1: {
                readonly address: "0xbEb5Fc579115071764c7423A4f12eDde41f106Ed";
            };
        };
        readonly l1StandardBridge: {
            readonly 1: {
                readonly address: "0x99C9fc46f92E8a1c0deC1b1747d010903E884bE1";
            };
        };
        readonly gasPriceOracle: {
            readonly address: "0x420000000000000000000000000000000000000F";
        };
        readonly l1Block: {
            readonly address: "0x4200000000000000000000000000000000000015";
        };
        readonly l2CrossDomainMessenger: {
            readonly address: "0x4200000000000000000000000000000000000007";
        };
        readonly l2Erc721Bridge: {
            readonly address: "0x4200000000000000000000000000000000000014";
        };
        readonly l2StandardBridge: {
            readonly address: "0x4200000000000000000000000000000000000010";
        };
        readonly l2ToL1MessagePasser: {
            readonly address: "0x4200000000000000000000000000000000000016";
        };
    };
    id: 10;
    name: "OP Mainnet";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://mainnet.optimism.io"];
        };
    };
    sourceId: 1;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters: {
        readonly block: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcBlock<viem.BlockTag, boolean, viem.RpcTransaction<boolean>>>, viem_chains.OpStackRpcBlockOverrides & {
                transactions: `0x${string}`[] | viem_chains.OpStackRpcTransaction<boolean>[];
            }>) => {
                baseFeePerGas: bigint | null;
                blobGasUsed: bigint;
                difficulty: bigint;
                excessBlobGas: bigint;
                extraData: `0x${string}`;
                gasLimit: bigint;
                gasUsed: bigint;
                hash: `0x${string}` | null;
                logsBloom: `0x${string}` | null;
                miner: `0x${string}`;
                mixHash: `0x${string}`;
                nonce: `0x${string}` | null;
                number: bigint | null;
                parentHash: `0x${string}`;
                receiptsRoot: `0x${string}`;
                sealFields: `0x${string}`[];
                sha3Uncles: `0x${string}`;
                size: bigint;
                stateRoot: `0x${string}`;
                timestamp: bigint;
                totalDifficulty: bigint | null;
                transactions: `0x${string}`[] | viem_chains.OpStackTransaction<boolean>[];
                transactionsRoot: `0x${string}`;
                uncles: `0x${string}`[];
                withdrawals?: viem.Withdrawal[] | undefined;
                withdrawalsRoot?: `0x${string}` | undefined;
            };
            type: "block";
        };
        readonly transaction: {
            exclude: [] | undefined;
            format: (args: ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x3";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            })) => {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity?: undefined;
                type: "legacy";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: undefined;
                maxPriorityFeePerGas: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "eip4844";
                gasPrice?: undefined;
                maxFeePerBlobGas: bigint;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            };
            type: "transaction";
        };
        readonly transactionReceipt: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcTransactionReceipt>, viem_chains.OpStackRpcTransactionReceiptOverrides>) => {
                blobGasPrice?: bigint | undefined;
                blobGasUsed?: bigint | undefined;
                blockHash: `0x${string}`;
                blockNumber: bigint;
                contractAddress: `0x${string}` | null | undefined;
                cumulativeGasUsed: bigint;
                effectiveGasPrice: bigint;
                from: `0x${string}`;
                gasUsed: bigint;
                logs: viem.Log<bigint, number, false, undefined, undefined, undefined, undefined>[];
                logsBloom: `0x${string}`;
                root?: `0x${string}` | undefined;
                status: "reverted" | "success";
                to: `0x${string}` | null;
                transactionHash: `0x${string}`;
                transactionIndex: number;
                type: viem.TransactionType;
                l1GasPrice: bigint | null;
                l1GasUsed: bigint | null;
                l1Fee: bigint | null;
                l1FeeScalar: number | null;
            };
            type: "transactionReceipt";
        };
    };
    serializers: {
        readonly transaction: typeof viem_chains.serializeTransactionOpStack;
    };
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Blockscout";
            readonly url: "https://optimism-sepolia.blockscout.com";
            readonly apiUrl: "https://optimism-sepolia.blockscout.com/api";
        };
    };
    contracts: {
        readonly disputeGameFactory: {
            readonly 11155111: {
                readonly address: "0x05F9613aDB30026FFd634f38e5C4dFd30a197Fa1";
            };
        };
        readonly l2OutputOracle: {
            readonly 11155111: {
                readonly address: "0x90E9c4f8a994a250F6aEfd61CAFb4F2e895D458F";
            };
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 1620204;
        };
        readonly portal: {
            readonly 11155111: {
                readonly address: "0x16Fc5058F25648194471939df75CF27A2fdC48BC";
            };
        };
        readonly l1StandardBridge: {
            readonly 11155111: {
                readonly address: "0xFBb0621E0B23b5478B630BD55a5f21f67730B0F1";
            };
        };
        readonly gasPriceOracle: {
            readonly address: "0x420000000000000000000000000000000000000F";
        };
        readonly l1Block: {
            readonly address: "0x4200000000000000000000000000000000000015";
        };
        readonly l2CrossDomainMessenger: {
            readonly address: "0x4200000000000000000000000000000000000007";
        };
        readonly l2Erc721Bridge: {
            readonly address: "0x4200000000000000000000000000000000000014";
        };
        readonly l2StandardBridge: {
            readonly address: "0x4200000000000000000000000000000000000010";
        };
        readonly l2ToL1MessagePasser: {
            readonly address: "0x4200000000000000000000000000000000000016";
        };
    };
    id: 11155420;
    name: "OP Sepolia";
    nativeCurrency: {
        readonly name: "Sepolia Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://sepolia.optimism.io"];
        };
    };
    sourceId: 11155111;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters: {
        readonly block: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcBlock<viem.BlockTag, boolean, viem.RpcTransaction<boolean>>>, viem_chains.OpStackRpcBlockOverrides & {
                transactions: `0x${string}`[] | viem_chains.OpStackRpcTransaction<boolean>[];
            }>) => {
                baseFeePerGas: bigint | null;
                blobGasUsed: bigint;
                difficulty: bigint;
                excessBlobGas: bigint;
                extraData: `0x${string}`;
                gasLimit: bigint;
                gasUsed: bigint;
                hash: `0x${string}` | null;
                logsBloom: `0x${string}` | null;
                miner: `0x${string}`;
                mixHash: `0x${string}`;
                nonce: `0x${string}` | null;
                number: bigint | null;
                parentHash: `0x${string}`;
                receiptsRoot: `0x${string}`;
                sealFields: `0x${string}`[];
                sha3Uncles: `0x${string}`;
                size: bigint;
                stateRoot: `0x${string}`;
                timestamp: bigint;
                totalDifficulty: bigint | null;
                transactions: `0x${string}`[] | viem_chains.OpStackTransaction<boolean>[];
                transactionsRoot: `0x${string}`;
                uncles: `0x${string}`[];
                withdrawals?: viem.Withdrawal[] | undefined;
                withdrawalsRoot?: `0x${string}` | undefined;
            };
            type: "block";
        };
        readonly transaction: {
            exclude: [] | undefined;
            format: (args: ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x3";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            })) => {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity?: undefined;
                type: "legacy";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: undefined;
                maxPriorityFeePerGas: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "eip4844";
                gasPrice?: undefined;
                maxFeePerBlobGas: bigint;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            };
            type: "transaction";
        };
        readonly transactionReceipt: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcTransactionReceipt>, viem_chains.OpStackRpcTransactionReceiptOverrides>) => {
                blobGasPrice?: bigint | undefined;
                blobGasUsed?: bigint | undefined;
                blockHash: `0x${string}`;
                blockNumber: bigint;
                contractAddress: `0x${string}` | null | undefined;
                cumulativeGasUsed: bigint;
                effectiveGasPrice: bigint;
                from: `0x${string}`;
                gasUsed: bigint;
                logs: viem.Log<bigint, number, false, undefined, undefined, undefined, undefined>[];
                logsBloom: `0x${string}`;
                root?: `0x${string}` | undefined;
                status: "reverted" | "success";
                to: `0x${string}` | null;
                transactionHash: `0x${string}`;
                transactionIndex: number;
                type: viem.TransactionType;
                l1GasPrice: bigint | null;
                l1GasUsed: bigint | null;
                l1Fee: bigint | null;
                l1FeeScalar: number | null;
            };
            type: "transactionReceipt";
        };
    };
    serializers: {
        readonly transaction: typeof viem_chains.serializeTransactionOpStack;
    };
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Arbiscan";
            readonly url: "https://arbiscan.io";
            readonly apiUrl: "https://api.arbiscan.io/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 7654707;
        };
    };
    id: 42161;
    name: "Arbitrum One";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://arb1.arbitrum.io/rpc"];
        };
    };
    sourceId?: number | undefined;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Arbiscan";
            readonly url: "https://nova.arbiscan.io";
            readonly apiUrl: "https://api-nova.arbiscan.io/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 1746963;
        };
    };
    id: 42170;
    name: "Arbitrum Nova";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://nova.arbitrum.io/rpc"];
        };
    };
    sourceId?: number | undefined;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Arbiscan";
            readonly url: "https://sepolia.arbiscan.io";
            readonly apiUrl: "https://api-sepolia.arbiscan.io/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 81930;
        };
    };
    id: 421614;
    name: "Arbitrum Sepolia";
    nativeCurrency: {
        readonly name: "Arbitrum Sepolia Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://sepolia-rollup.arbitrum.io/rpc"];
        };
    };
    sourceId?: number | undefined;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Basescan";
            readonly url: "https://basescan.org";
            readonly apiUrl: "https://api.basescan.org/api";
        };
    };
    contracts: {
        readonly l2OutputOracle: {
            readonly 1: {
                readonly address: "0x56315b90c40730925ec5485cf004d835058518A0";
            };
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 5022;
        };
        readonly portal: {
            readonly 1: {
                readonly address: "0x49048044D57e1C92A77f79988d21Fa8fAF74E97e";
                readonly blockCreated: 17482143;
            };
        };
        readonly l1StandardBridge: {
            readonly 1: {
                readonly address: "0x3154Cf16ccdb4C6d922629664174b904d80F2C35";
                readonly blockCreated: 17482143;
            };
        };
        readonly gasPriceOracle: {
            readonly address: "0x420000000000000000000000000000000000000F";
        };
        readonly l1Block: {
            readonly address: "0x4200000000000000000000000000000000000015";
        };
        readonly l2CrossDomainMessenger: {
            readonly address: "0x4200000000000000000000000000000000000007";
        };
        readonly l2Erc721Bridge: {
            readonly address: "0x4200000000000000000000000000000000000014";
        };
        readonly l2StandardBridge: {
            readonly address: "0x4200000000000000000000000000000000000010";
        };
        readonly l2ToL1MessagePasser: {
            readonly address: "0x4200000000000000000000000000000000000016";
        };
    };
    id: 8453;
    name: "Base";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://mainnet.base.org"];
        };
    };
    sourceId: 1;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters: {
        readonly block: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcBlock<viem.BlockTag, boolean, viem.RpcTransaction<boolean>>>, viem_chains.OpStackRpcBlockOverrides & {
                transactions: `0x${string}`[] | viem_chains.OpStackRpcTransaction<boolean>[];
            }>) => {
                baseFeePerGas: bigint | null;
                blobGasUsed: bigint;
                difficulty: bigint;
                excessBlobGas: bigint;
                extraData: `0x${string}`;
                gasLimit: bigint;
                gasUsed: bigint;
                hash: `0x${string}` | null;
                logsBloom: `0x${string}` | null;
                miner: `0x${string}`;
                mixHash: `0x${string}`;
                nonce: `0x${string}` | null;
                number: bigint | null;
                parentHash: `0x${string}`;
                receiptsRoot: `0x${string}`;
                sealFields: `0x${string}`[];
                sha3Uncles: `0x${string}`;
                size: bigint;
                stateRoot: `0x${string}`;
                timestamp: bigint;
                totalDifficulty: bigint | null;
                transactions: `0x${string}`[] | viem_chains.OpStackTransaction<boolean>[];
                transactionsRoot: `0x${string}`;
                uncles: `0x${string}`[];
                withdrawals?: viem.Withdrawal[] | undefined;
                withdrawalsRoot?: `0x${string}` | undefined;
            };
            type: "block";
        };
        readonly transaction: {
            exclude: [] | undefined;
            format: (args: ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x3";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            })) => {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity?: undefined;
                type: "legacy";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: undefined;
                maxPriorityFeePerGas: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "eip4844";
                gasPrice?: undefined;
                maxFeePerBlobGas: bigint;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            };
            type: "transaction";
        };
        readonly transactionReceipt: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcTransactionReceipt>, viem_chains.OpStackRpcTransactionReceiptOverrides>) => {
                blobGasPrice?: bigint | undefined;
                blobGasUsed?: bigint | undefined;
                blockHash: `0x${string}`;
                blockNumber: bigint;
                contractAddress: `0x${string}` | null | undefined;
                cumulativeGasUsed: bigint;
                effectiveGasPrice: bigint;
                from: `0x${string}`;
                gasUsed: bigint;
                logs: viem.Log<bigint, number, false, undefined, undefined, undefined, undefined>[];
                logsBloom: `0x${string}`;
                root?: `0x${string}` | undefined;
                status: "reverted" | "success";
                to: `0x${string}` | null;
                transactionHash: `0x${string}`;
                transactionIndex: number;
                type: viem.TransactionType;
                l1GasPrice: bigint | null;
                l1GasUsed: bigint | null;
                l1Fee: bigint | null;
                l1FeeScalar: number | null;
            };
            type: "transactionReceipt";
        };
    };
    serializers: {
        readonly transaction: typeof viem_chains.serializeTransactionOpStack;
    };
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Basescan";
            readonly url: "https://sepolia.basescan.org";
            readonly apiUrl: "https://api-sepolia.basescan.org/api";
        };
    };
    contracts: {
        readonly l2OutputOracle: {
            readonly 11155111: {
                readonly address: "0x84457ca9D0163FbC4bbfe4Dfbb20ba46e48DF254";
            };
        };
        readonly portal: {
            readonly 11155111: {
                readonly address: "0x49f53e41452c74589e85ca1677426ba426459e85";
                readonly blockCreated: 4446677;
            };
        };
        readonly l1StandardBridge: {
            readonly 11155111: {
                readonly address: "0xfd0Bf71F60660E2f608ed56e1659C450eB113120";
                readonly blockCreated: 4446677;
            };
        };
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 1059647;
        };
        readonly gasPriceOracle: {
            readonly address: "0x420000000000000000000000000000000000000F";
        };
        readonly l1Block: {
            readonly address: "0x4200000000000000000000000000000000000015";
        };
        readonly l2CrossDomainMessenger: {
            readonly address: "0x4200000000000000000000000000000000000007";
        };
        readonly l2Erc721Bridge: {
            readonly address: "0x4200000000000000000000000000000000000014";
        };
        readonly l2StandardBridge: {
            readonly address: "0x4200000000000000000000000000000000000010";
        };
        readonly l2ToL1MessagePasser: {
            readonly address: "0x4200000000000000000000000000000000000016";
        };
    };
    id: 84532;
    name: "Base Sepolia";
    nativeCurrency: {
        readonly name: "Sepolia Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://sepolia.base.org"];
        };
    };
    sourceId: 11155111;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters: {
        readonly block: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcBlock<viem.BlockTag, boolean, viem.RpcTransaction<boolean>>>, viem_chains.OpStackRpcBlockOverrides & {
                transactions: `0x${string}`[] | viem_chains.OpStackRpcTransaction<boolean>[];
            }>) => {
                baseFeePerGas: bigint | null;
                blobGasUsed: bigint;
                difficulty: bigint;
                excessBlobGas: bigint;
                extraData: `0x${string}`;
                gasLimit: bigint;
                gasUsed: bigint;
                hash: `0x${string}` | null;
                logsBloom: `0x${string}` | null;
                miner: `0x${string}`;
                mixHash: `0x${string}`;
                nonce: `0x${string}` | null;
                number: bigint | null;
                parentHash: `0x${string}`;
                receiptsRoot: `0x${string}`;
                sealFields: `0x${string}`[];
                sha3Uncles: `0x${string}`;
                size: bigint;
                stateRoot: `0x${string}`;
                timestamp: bigint;
                totalDifficulty: bigint | null;
                transactions: `0x${string}`[] | viem_chains.OpStackTransaction<boolean>[];
                transactionsRoot: `0x${string}`;
                uncles: `0x${string}`[];
                withdrawals?: viem.Withdrawal[] | undefined;
                withdrawalsRoot?: `0x${string}` | undefined;
            };
            type: "block";
        };
        readonly transaction: {
            exclude: [] | undefined;
            format: (args: ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x0";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                yParity?: undefined;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x1";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice: `0x${string}`;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x2";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & {
                type: "0x3";
                r: `0x${string}`;
                s: `0x${string}`;
                v: `0x${string}`;
                gasPrice?: undefined;
                maxFeePerBlobGas: `0x${string}`;
                maxFeePerGas: `0x${string}`;
                maxPriorityFeePerGas: `0x${string}`;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: `0x${string}`;
                nonce: `0x${string}`;
                value: `0x${string}`;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                blockHash: `0x${string}` | null;
                blockNumber: `0x${string}` | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: `0x${string}` | null;
                chainId: `0x${string}`;
                yParity?: `0x${string}` | undefined;
            } & {
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            }) | ({
                type?: "0x0" | "0x1" | "0x2" | "0x3" | "0x7e" | undefined;
                r?: `0x${string}` | undefined;
                s?: `0x${string}` | undefined;
                v?: `0x${string}` | undefined;
                gasPrice?: `0x${string}` | undefined;
                maxFeePerBlobGas?: `0x${string}` | undefined;
                maxFeePerGas?: `0x${string}` | undefined;
                maxPriorityFeePerGas?: `0x${string}` | undefined;
                to?: `0x${string}` | null | undefined;
                from?: `0x${string}` | undefined;
                gas?: `0x${string}` | undefined;
                nonce?: `0x${string}` | undefined;
                value?: `0x${string}` | undefined;
                accessList?: viem.AccessList | undefined;
                blobVersionedHashes?: readonly `0x${string}`[] | undefined;
                blockHash?: `0x${string}` | null | undefined;
                blockNumber?: `0x${string}` | null | undefined;
                hash?: `0x${string}` | undefined;
                input?: `0x${string}` | undefined;
                transactionIndex?: `0x${string}` | null | undefined;
                chainId?: `0x${string}` | undefined;
                yParity?: `0x${string}` | undefined;
            } & Omit<viem.TransactionBase<`0x${string}`, `0x${string}`, boolean>, "typeHex"> & viem.FeeValuesEIP1559<`0x${string}`> & {
                isSystemTx?: boolean | undefined;
                mint?: `0x${string}` | undefined;
                sourceHash: `0x${string}`;
                type: "0x7e";
            })) => {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity?: undefined;
                type: "legacy";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                r: `0x${string}`;
                s: `0x${string}`;
                v: bigint;
                to: `0x${string}` | null;
                from: `0x${string}`;
                gas: bigint;
                nonce: number;
                value: bigint;
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                hash: `0x${string}`;
                input: `0x${string}`;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                accessList?: undefined;
                blobVersionedHashes?: undefined;
                chainId?: number | undefined;
                yParity: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas?: undefined;
                maxPriorityFeePerGas?: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip2930";
                gasPrice: bigint;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: undefined;
                maxPriorityFeePerGas: undefined;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "eip1559";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes?: undefined;
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas?: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "eip4844";
                gasPrice?: undefined;
                maxFeePerBlobGas: bigint;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: undefined;
                mint?: undefined;
                sourceHash?: undefined;
            } | {
                blockHash: `0x${string}` | null;
                blockNumber: bigint | null;
                from: `0x${string}`;
                gas: bigint;
                hash: `0x${string}`;
                input: `0x${string}`;
                nonce: number;
                r: `0x${string}`;
                s: `0x${string}`;
                to: `0x${string}` | null;
                transactionIndex: number | null;
                typeHex: `0x${string}` | null;
                v: bigint;
                value: bigint;
                yParity: number;
                accessList: viem.AccessList;
                blobVersionedHashes: readonly `0x${string}`[];
                chainId: number;
                type: "deposit";
                gasPrice?: undefined;
                maxFeePerBlobGas: undefined;
                maxFeePerGas: bigint;
                maxPriorityFeePerGas: bigint;
                isSystemTx?: boolean | undefined;
                mint?: bigint | undefined;
                sourceHash: `0x${string}`;
            };
            type: "transaction";
        };
        readonly transactionReceipt: {
            exclude: [] | undefined;
            format: (args: viem_chains.Assign<viem.ExactPartial<viem.RpcTransactionReceipt>, viem_chains.OpStackRpcTransactionReceiptOverrides>) => {
                blobGasPrice?: bigint | undefined;
                blobGasUsed?: bigint | undefined;
                blockHash: `0x${string}`;
                blockNumber: bigint;
                contractAddress: `0x${string}` | null | undefined;
                cumulativeGasUsed: bigint;
                effectiveGasPrice: bigint;
                from: `0x${string}`;
                gasUsed: bigint;
                logs: viem.Log<bigint, number, false, undefined, undefined, undefined, undefined>[];
                logsBloom: `0x${string}`;
                root?: `0x${string}` | undefined;
                status: "reverted" | "success";
                to: `0x${string}` | null;
                transactionHash: `0x${string}`;
                transactionIndex: number;
                type: viem.TransactionType;
                l1GasPrice: bigint | null;
                l1GasUsed: bigint | null;
                l1Fee: bigint | null;
                l1FeeScalar: number | null;
            };
            type: "transactionReceipt";
        };
    };
    serializers: {
        readonly transaction: typeof viem_chains.serializeTransactionOpStack;
    };
    readonly network: "base-sepolia";
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "zKyoto Explorer";
            readonly url: "https://zkyoto.explorer.startale.com";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 196153;
        };
    };
    id: 6038361;
    name: "Astar zkEVM Testnet zKyoto";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc.startale.com/zkyoto"];
        };
    };
    sourceId?: number | undefined;
    testnet: true;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
    readonly network: "zKyoto";
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "Astar zkEVM Explorer";
            readonly url: "https://astar-zkevm.explorer.startale.com";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 93528;
        };
    };
    id: 3776;
    name: "Astar zkEVM";
    nativeCurrency: {
        readonly name: "Ether";
        readonly symbol: "ETH";
        readonly decimals: 18;
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc.startale.com/astar-zkevm"];
        };
    };
    sourceId?: number | undefined;
    testnet: false;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
    readonly network: "AstarZkEVM";
} | {
    blockExplorers: {
        readonly default: {
            readonly name: "BscScan";
            readonly url: "https://bscscan.com";
            readonly apiUrl: "https://api.bscscan.com/api";
        };
    };
    contracts: {
        readonly multicall3: {
            readonly address: "0xca11bde05977b3631167028862be2a173976ca11";
            readonly blockCreated: 15921452;
        };
    };
    id: 56;
    name: "BNB Smart Chain";
    nativeCurrency: {
        readonly decimals: 18;
        readonly name: "BNB";
        readonly symbol: "BNB";
    };
    rpcUrls: {
        readonly default: {
            readonly http: readonly ["https://rpc.ankr.com/bsc"];
        };
    };
    sourceId?: number | undefined;
    testnet?: boolean | undefined;
    custom?: Record<string, unknown> | undefined;
    fees?: viem.ChainFees<undefined> | undefined;
    formatters?: undefined;
    serializers?: viem.ChainSerializers<undefined, viem.TransactionSerializable<bigint, number>> | undefined;
};
declare const getBundlerRPC: (chain: EVMBlockchainIncludingTestnet) => string;

declare const parseToken: (token: any) => any;

declare class NotAuthorizedError extends Error {
    code: string;
    constructor(message: string);
}
declare class TransferError extends Error {
    code: string;
    constructor(message: string);
}
declare class TransactionError extends Error {
    code: string;
    constructor(message: string);
}
declare class CrossmintServiceError extends Error {
    code: string;
    status?: number;
    constructor(message: string, status?: number);
}
/**
 * Generic undefined error
 */
declare class WalletSdkError extends Error {
    code: string;
    constructor(message: string);
}
declare function errorToJSON(error: Error | unknown): any;

type CreateOwnerSignerInput = {
    chain: EVMBlockchainIncludingTestnet;
    walletConfig: WalletConfig;
};
declare const createOwnerSigner: (args_0: CreateOwnerSignerInput) => Promise<SmartAccountSigner<"custom", `0x${string}`>>;
declare function isAccount(signer: any): signer is ViemAccount;

declare function isLocalhost(): boolean;
declare function isEmpty(str: string | undefined | null): str is undefined | null;

declare function usesGelatoBundler(chain: EVMBlockchainIncludingTestnet): boolean;
declare const gelatoBundlerProperties: {
    maxFeePerGas: any;
    maxPriorityFeePerGas: any;
};

declare class SmartWalletSDK extends LoggerWrapper {
    private readonly crossmintService;
    private readonly eaoWalletService;
    private readonly passkeyWalletService;
    private constructor();
    /**
     * Initializes the SDK with the **client side** API key obtained from the Crossmint console.
     * @throws error if the api key is not formatted correctly.
     */
    static init(config: SmartWalletSDKInitParams): SmartWalletSDK;
    getOrCreateWallet(user: UserParams, chain: EVMBlockchainIncludingTestnet, walletConfig: WalletConfig): Promise<EVMSmartWallet>;
    private fetchEntryPoint;
}

export { CrossmintServiceError, CrossmintWalletService, type EOASigner, type EOASignerData, type ERC2OEVMToken, EVMSmartWallet, type EVMToken, type EntryPointDetails, type NFTEVMToken, NotAuthorizedError, type PasskeySigner, type PasskeySignerData, type SFTEVMToken, type SignerData, SmartWalletSDK, type SmartWalletSDKInitParams, type StoreAbstractWalletInput, type TokenType, TransactionError, TransferError, type UserParams, type ViemAccount, type WalletConfig, WalletSdkError, type Web3AuthSigner, createOwnerSigner, errorToJSON, gelatoBundlerProperties, getBlockExplorerByBlockchain, getBundlerRPC, getTickerByBlockchain, getTickerNameByBlockchain, getUrlProviderByBlockchain, getViemNetwork, getZeroDevProjectIdByBlockchain, isAccount, isEmpty, isLocalhost, parseToken, usesGelatoBundler };
